#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_settings_ap_pnp_location
short_description: Resource module for System Settings
  Ap Pnp Location
description:
  - Manage operation update of the resource System Settings
    Ap Pnp Location. - > Enable or disable the AP PnP
    Location setting in the system.Once the AP PnP Location
    Setting is enabled, the Access Point's assigned
    Site name will be configured as the AP Location
    during the PnP Claim process. This applies only
    during the PnP onboarding process and not during
    any subsequent provisioning dayN .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apPnPLocation:
    description: Enable Or Disable.Once the AP PnP Location
      Setting is enabled, the Access Point's assigned
      Site name will be configured as the AP Location
      during the PnP Claim process. This applies only
      during the PnP onboarding process and not during
      any subsequent provisioning (dayN).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      UpdateAPPnPLocationSetting
    description: Complete reference of the UpdateAPPnPLocationSetting
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-ap-pn-p-location-setting
notes:
  - SDK Method used are
    wireless.Wireless.update_ap_pnp_location_setting,
  - Paths used are
    put /dna/intent/api/v1/systemSettings/apPnpLocation,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.system_settings_ap_pnp_location:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apPnPLocation: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_controllers_ssid_details_count_info
short_description: Information module for Wireless Controllers
  Ssid Details Count
description:
  - Get all Wireless Controllers Ssid Details Count.
  - Retrieves the count of SSIDs associated with the
    specific wireless controller.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - >
        NetworkDeviceId path parameter. Obtain the network
        device ID value by using the API call GET /dna/intent/api/v1/network-device/ip-address/${ipAddress}.
    type: str
  adminStatus:
    description:
      - >
        AdminStatus query parameter. Utilize this query
        parameter to obtain the number of SSIDs according
        to their administrative status. A 'true' value
        signifies that the admin status of the SSID
        is enabled, while a 'false' value indicates
        that the admin status of the SSID is disabled.
    type: bool
  managed:
    description:
      - >
        Managed query parameter. If value is 'true'
        means SSIDs are configured through design.If
        the value is 'false' means out of band configuration
        from the Wireless Controller.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetSSIDCountForSpecificWirelessController
    description: Complete reference of the GetSSIDCountForSpecificWirelessController
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ssid-count-for-specific-wireless-controller
notes:
  - SDK Method used are
    wireless.Wireless.get_ssid_count_for_specific_wireless_controller,
  - Paths used are
    get /dna/intent/api/v1/wirelessControllers/{networkDeviceId}/ssidDetails/count,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Controllers Ssid Details Count
  cisco.dnac.wireless_controllers_ssid_details_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    adminStatus: true
    managed: true
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_maintenance_schedules_id
short_description: Resource module for Network Device
  Maintenance Schedules Id
description:
  - Manage operations update and delete of the resource
    Network Device Maintenance Schedules Id. - > API
    to delete maintenance schedule by id. Deletion is
    allowed if the maintenance window is in the `UPCOMING`,
    `COMPLETED`, or `FAILED` state. Deletion of maintenance
    schedule is not allowed if the maintenance window
    is currently `IN_PROGRESS`. To delete the maintenance
    schedule while it is `IN_PROGRESS`, first exit the
    current maintenance window using `PUT /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id}`
    API, and then proceed to delete the maintenance
    schedule. - > API to update the maintenance schedule
    for the network devices. The `maintenanceSchedule`
    can be updated only if the `status` value is `UPCOMING`
    or `IN_PROGRESS`. User can exit `IN_PROGRESS` maintenance
    window by setting the `endTime` to -1. This will
    update the endTime to the current time and exit
    the maintenance window immediately. When exiting
    the maintenance window, only the endTime will be
    updated while other parameters remain read-only.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  description:
    description: A brief narrative describing the maintenance
      schedule.
    type: str
  id:
    description: Id path parameter. Unique identifier
      for the maintenance schedule.
    type: str
  maintenanceSchedule:
    description: Network Device Maintenance Schedules
      Id's maintenanceSchedule.
    suboptions:
      endTime:
        description: End time indicates the ending of
          the maintenance window in Unix epoch time
          in milliseconds.
        type: float
      recurrence:
        description: Network Device Maintenance Schedules
          Id's recurrence.
        suboptions:
          interval:
            description: Interval for recurrence in
              days. The interval must be longer than
              the duration of the schedules. The maximum
              allowed interval is 365 days.
            type: int
          recurrenceEndTime:
            description: The end date for the recurrence
              in Unix epoch time in milliseconds. Recurrence
              end time should be greater than maintenance
              end date/time.
            type: float
        type: dict
      startTime:
        description: Start time indicates the beginning
          of the maintenance window in Unix epoch time
          in milliseconds.
        type: float
    type: dict
  networkDeviceIds:
    description: List of network device ids. This field
      is applicable only during creation of schedules;
      for updates, it is read-only.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      DeleteMaintenanceSchedule
    description: Complete reference of the DeleteMaintenanceSchedule
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-maintenance-schedule
  - name: Cisco DNA Center documentation for Devices
      UpdatesTheMaintenanceScheduleInformation
    description: Complete reference of the UpdatesTheMaintenanceScheduleInformation
      API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-the-maintenance-schedule-information
notes:
  - SDK Method used are
    devices.Devices.delete_maintenance_schedule,
    devices.Devices.updates_the_maintenance_schedule_information,
  - Paths used are
    delete /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id},
    put /dna/intent/api/v1/networkDeviceMaintenanceSchedules/{id},
"""

EXAMPLES = r"""
---
- name: Update by id
  cisco.dnac.network_device_maintenance_schedules_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    description: string
    id: string
    maintenanceSchedule:
      endTime: 0
      recurrence:
        interval: 0
        recurrenceEndTime: 0
      startTime: 0
    networkDeviceIds:
      - string
- name: Delete by id
  cisco.dnac.network_device_maintenance_schedules_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_service_insertions_id
short_description: Resource module for Security Service
  Insertions Id
description:
  - Manage operations update and delete of the resource
    Security Service Insertions Id.
  - Removes the Security Service Insertion SSI configuration
    from the fabric site where it was created. - > Updates
    the Security Service Insertion SSI. It allows modifications
    to the associated Virtual Networks VNs , border
    devices, and firewall ips.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. The unique identifier
      of the Security Service Insertion (SSI).
    type: str
  siteId:
    description: The ID of the fabric site where the
      service insertion is configured.
    type: str
  virtualNetworks:
    description: Security Service Insertions Id's virtualNetworks.
    elements: dict
    suboptions:
      devices:
        description: Security Service Insertions Id's
          devices.
        elements: dict
        suboptions:
          id:
            description: The unique identifier of the
              network device.
            type: str
          layer3Handoffs:
            description: Security Service Insertions
              Id's layer3Handoffs.
            elements: dict
            suboptions:
              firewallIpV4AddressWithMask:
                description: The IPv4 address and subnet
                  mask of the firewall.
                type: str
            type: list
        type: list
      name:
        description: Name of the virtual network associated
          with the fabric site.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA DeleteSecurityServiceInsertion
    description: Complete reference of the DeleteSecurityServiceInsertion
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-security-service-insertion
  - name: Cisco DNA Center documentation for SDA UpdateTheSecurityServiceInsertion
    description: Complete reference of the UpdateTheSecurityServiceInsertion
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-the-security-service-insertion
notes:
  - SDK Method used are
    sda.Sda.delete_security_service_insertion,
    sda.Sda.update_the_security_service_insertion,
  - Paths used are
    delete /dna/intent/api/v1/securityServiceInsertions/{id},
    put /dna/intent/api/v1/securityServiceInsertions/{id},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.security_service_insertions_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.security_service_insertions_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
    siteId: string
    virtualNetworks:
      - devices:
          - id: string
            layer3Handoffs:
              - firewallIpV4AddressWithMask: string
        name: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_threats_type_info
short_description: Information module for Security Threats
  Type
description:
  - Get all Security Threats Type.
  - Intent API to fetch all threat types defined.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
notes:
  - SDK Method used are
    devices.Devices.get_threat_types,
  - Paths used are
    get /dna/intent/api/v1/security/threats/type,
"""

EXAMPLES = r"""
---
- name: Get all Security Threats Type
  cisco.dnac.security_threats_type_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "value": 0,
        "name": "string",
        "label": "string",
        "isCustom": true,
        "isDeleted": true
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: backup_restore_executions_info
short_description: Information module for Backup Restore
  Executions
description:
  - Get all Backup Restore Executions.
  - This api is used to get all the backup and restore
    executions.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  backupId:
    description:
      - >
        BackupId query parameter. The `backupId` of
        the backup execution to be retrieved.Obtain
        the `backupId` from the id attribute in the
        response of the `/dna/system/api/v1/backups`
        API.
    type: str
  jobType:
    description:
      - JobType query parameter. The `jobType` of the
        backup execution to be retrieved.
    type: str
  status:
    description:
      - Status query parameter. The `status` of the
        backup execution to be retrieved.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or
        descending order should be used to sort the
        response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Backup
      GetBackupAndRestoreExecutions
    description: Complete reference of the GetBackupAndRestoreExecutions
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-backup-and-restore-executions
notes:
  - SDK Method used are
    backup.Backup.get_backup_and_restore_executions,
  - Paths used are
    get /dna/system/api/v1/backupRestoreExecutions,
"""

EXAMPLES = r"""
---
- name: Get all Backup Restore Executions
  cisco.dnac.backup_restore_executions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    backupId: string
    jobType: string
    status: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "filter": {},
      "page": {},
      "response": [
        {
          "_metadata": {},
          "backupId": "string",
          "completedPercentage": 0,
          "createdBy": "string",
          "duration": 0,
          "endDate": "string",
          "errorCode": "string",
          "errorMessage": "string",
          "failedTaskDetail": {},
          "id": "string",
          "isForceUpdate": true,
          "jobType": "string",
          "scope": "string",
          "startDate": "string",
          "status": "string",
          "systemErrorMessage": "string",
          "updateMessage": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_issue_definitions_info
short_description: Information module for System Issue
  Definitions
description:
  - Get all System Issue Definitions. - > Get all system
    issue defintions. The supported filters are id,
    name, profileId and definition enable status. An
    issue trigger definition can be different across
    the profile and device type. So, `profileId` and
    `deviceType` in the query param is important and
    default is global profile and all device type. For
    detailed information about the usage of the API,
    please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    issueAndHealthDefinitions-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceType:
    description:
      - >
        DeviceType query parameter. These are the device
        families/types supported for system issue definitions.
        If no input is made on device type, all device
        types are considered.
    type: str
  profileId:
    description:
      - >
        ProfileId query parameter. The profile identier
        to fetch the profile associated issue defintions.
        The default is `global`. Please refer Network
        design profiles documentation for more details.
    type: str
  id:
    description:
      - >
        Id query parameter. The definition identifier.
        Examples id=015d9cba-4f53-4087-8317-7e49e5ffef46
        (single entity id request) id=015d9cba-4f53-4087-8317-7e49e5ffef46&id=015d9cba-4f53-4087-8317-7e49e5ffef47
        (multiple ids in the query param).
    type: str
  name:
    description:
      - >
        Name query parameter. The list of system defined
        issue names. (Ex."BGP_Down") Examples name=BGP_Down
        (single entity uuid requested) name=BGP_Down&name=BGP_Flap
        (multiple issue names separated by & operator).
    type: str
  priority:
    description:
      - >
        Priority query parameter. Issue priority, possible
        values are P1, P2, P3, P4. `P1` A critical issue
        that needs immediate attention and can have
        a wide impact on network operations. `P2` A
        major issue that can potentially impact multiple
        devices or clients. `P3` A minor issue that
        has a localized or minimal impact. `P4` A warning
        issue that may not be an immediate problem but
        addressing it can optimize the network performance.
    type: str
  issueEnabled:
    description:
      - IssueEnabled query parameter. The enablement
        status of the issue definition, either true
        or false.
    type: bool
  attribute:
    description:
      - >
        Attribute query parameter. These are the attributes
        supported in system issue definitions response.
        By default, all properties are sent in response.
    type: str
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Issues
      ReturnsAllIssueTriggerDefinitionsForGivenFilters
    description: Complete reference of the ReturnsAllIssueTriggerDefinitionsForGivenFilters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!returns-all-issue-trigger-definitions-for-given-filters
notes:
  - SDK Method used are
    issues.Issues.returns_all_issue_trigger_definitions_for_given_filters,
  - Paths used are
    get /dna/intent/api/v1/systemIssueDefinitions,
"""

EXAMPLES = r"""
---
- name: Get all System Issue Definitions
  cisco.dnac.system_issue_definitions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceType: string
    profileId: string
    id: string
    name: string
    priority: string
    issueEnabled: true
    attribute: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "id": "string",
        "name": "string",
        "displayName": "string",
        "description": "string",
        "priority": "string",
        "defaultPriority": "string",
        "deviceType": "string",
        "issueEnabled": true,
        "profileId": "string",
        "definitionStatus": "string",
        "categoryName": "string",
        "synchronizeToHealthThreshold": true,
        "thresholdValue": 0,
        "lastModified": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: fabrics_fabric_id_wireless_multicast
short_description: Resource module for Fabrics Fabric
  Id Wireless Multicast
description:
  - Manage operation update of the resource Fabrics
    Fabric Id Wireless Multicast. - > Updates the Software-Defined
    Access SDA Wireless Multicast setting for a specified
    fabric site. This API allows you to enable or disable
    the multicast feature. For optimal performance,
    ensure wired multicast is also enabled.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  fabricId:
    description: FabricId path parameter. The unique
      identifier of the fabric site for which the multicast
      setting is being requested. The identifier should
      be in the format of a UUID. The 'fabricId' can
      be obtained using the api /dna/intent/api/v1/sda/fabricSites.
    type: str
  multicastEnabled:
    description: Multicast Enabled.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Fabric
      Wireless UpdateSDAWirelessMulticast
    description: Complete reference of the UpdateSDAWirelessMulticast
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-sda-wireless-multicast
notes:
  - SDK Method used are
    fabric_wireless.FabricWireless.update_sda_wireless_multicast,
  - Paths used are
    put /dna/intent/api/v1/sda/fabrics/{fabricId}/wirelessMulticast,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.fabrics_fabric_id_wireless_multicast:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    fabricId: string
    multicastEnabled: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ipam_global_ip_address_pools_global_ip_address_pool_id_subpools_info
short_description: Information module for Ipam Global
  Ip Address Pools Global Ip Address Pool Id Subpools
description:
  - Get all Ipam Global Ip Address Pools Global Ip Address
    Pool Id Subpools. - > Retrieves subpools IDs of
    a global IP address pool. The IDs can be fetched
    with `/dna/intent/api/v1/ipam/siteIpAddressPools/{id}`.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  globalIpAddressPoolId:
    description:
      - GlobalIpAddressPoolId path parameter. The `id`
        of the global IP address pool for which to retrieve
        subpool IDs.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page; the minimum is 1, and
        the maximum is 500.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings RetrievesSubpoolsIDsOfAGlobalIPAddressPool
    description: Complete reference of the RetrievesSubpoolsIDsOfAGlobalIPAddressPool
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-subpools-i-ds-of-a-global-ip-address-pool
notes:
  - SDK Method used are
    network_settings.NetworkSettings.retrieves_subpools_ids_of_a_global_ip_address_pool,
  - Paths used are
    get /dna/intent/api/v1/ipam/globalIpAddressPools/{globalIpAddressPoolId}/subpools,
"""

EXAMPLES = r"""
---
- name: Get all Ipam Global Ip Address Pools Global
    Ip Address Pool Id Subpools
  cisco.dnac.ipam_global_ip_address_pools_global_ip_address_pool_id_subpools_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    globalIpAddressPoolId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_query
short_description: Resource module for Network Devices
  Query
description:
  - Manage operation create of the resource Network
    Devices Query. - > Gets the list of Network Devices
    based on the provided complex filters and aggregation
    functions. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AssuranceNetworkDevices-2.0.1-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Network Devices Query's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Network Devices Query's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  page:
    description: Network Devices Query's page.
    suboptions:
      count:
        description: Count.
        type: int
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Sort By.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
  views:
    description: Views.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetsTheListOfNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
    description: Complete reference of the GetsTheListOfNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-list-of-network-devices-based-on-the-provided-complex-filters-and-aggregation-functions
notes:
  - SDK Method used are
    devices.Devices.gets_the_list_of_network_devices_based_on_the_provided_complex_filters_and_aggregation_functions,
  - Paths used are
    post /dna/data/api/v1/networkDevices/query,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.network_devices_query:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    page:
      count: 0
      limit: 0
      offset: 0
      sortBy: string
    startTime: 0
    views:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "managementIpAddress": "string",
          "platformId": "string",
          "deviceFamily": "string",
          "serialNumber": "string",
          "macAddress": "string",
          "deviceSeries": "string",
          "softwareVersion": "string",
          "productVendor": "string",
          "deviceRole": "string",
          "deviceType": "string",
          "communicationState": "string",
          "collectionStatus": "string",
          "haStatus": "string",
          "lastBootTime": 0,
          "siteHierarchyId": "string",
          "siteHierarchy": "string",
          "siteId": "string",
          "deviceGroupHierarchyId": "string",
          "tagNames": [
            "string"
          ],
          "stackType": "string",
          "osType": "string",
          "ringStatus": true,
          "maintenanceModeEnabled": true,
          "upTime": 0,
          "ipv4Address": "string",
          "ipv6Address": "string",
          "redundancyMode": "string",
          "featureFlagList": [
            "string"
          ],
          "haLastResetReason": "string",
          "redundancyPeerStateDerived": "string",
          "redundancyPeerState": "string",
          "redundancyStateDerived": "string",
          "redundancyState": "string",
          "wiredClientCount": 0,
          "wirelessClientCount": 0,
          "portCount": 0,
          "physicalPortCount": 0,
          "virtualPortCount": 0,
          "clientCount": 0,
          "apDetails": {
            "connectedWlcName": "string",
            "policyTagName": "string",
            "apOperationalState": "string",
            "powerSaveMode": "string",
            "operationalMode": "string",
            "resetReason": "string",
            "protocol": "string",
            "powerMode": "string",
            "connectedTime": 0,
            "ledFlashEnabled": true,
            "ledFlashSeconds": 0,
            "subMode": "string",
            "homeApEnabled": true,
            "powerType": "string",
            "apType": "string",
            "adminState": "string",
            "icapCapability": "string",
            "regulatoryDomain": "string",
            "ethernetMac": "string",
            "rfTagName": "string",
            "siteTagName": "string",
            "powerSaveModeCapable": "string",
            "powerProfile": "string",
            "flexGroup": "string",
            "powerCalendarProfile": "string",
            "apGroup": "string",
            "radios": [
              {
                "id": "string",
                "band": "string",
                "noise": 0,
                "airQuality": 0,
                "interference": 0,
                "trafficUtil": 0,
                "utilization": 0,
                "clientCount": 0
              }
            ]
          },
          "metricsDetails": {
            "overallHealthScore": 0,
            "cpuUtilization": 0,
            "cpuScore": 0,
            "memoryUtilization": 0,
            "memoryScore": 0,
            "avgTemperature": 0,
            "maxTemperature": 0,
            "discardScore": 0,
            "discardInterfaces": [
              "string"
            ],
            "errorScore": 0,
            "errorInterfaces": [
              "string"
            ],
            "interDeviceLinkScore": 0,
            "interDeviceConnectedDownInterfaces": [
              "string"
            ],
            "linkUtilizationScore": 0,
            "highLinkUtilizationInterfaces": [
              "string"
            ],
            "freeTimerScore": 0,
            "freeTimer": 0,
            "packetPoolScore": 0,
            "packetPool": 0,
            "freeMemoryBufferScore": 0,
            "freeMemoryBuffer": 0,
            "wqePoolScore": 0,
            "wqePool": 0,
            "apCount": 0,
            "noiseScore": 0,
            "utilizationScore": 0,
            "interferenceScore": 0,
            "airQualityScore": 0
          },
          "fabricDetails": {
            "fabricRole": [
              "string"
            ],
            "fabricSiteName": "string",
            "transitFabrics": [
              "string"
            ],
            "l2Vns": [
              "string"
            ],
            "l3Vns": [
              "string"
            ],
            "fabricSiteId": "string",
            "networkProtocol": "string"
          },
          "switchPoeDetails": {
            "portCount": 0,
            "usedPortCount": 0,
            "freePortCount": 0,
            "powerConsumed": 0,
            "poePowerConsumed": 0,
            "systemPowerConsumed": 0,
            "powerBudget": 0,
            "poePowerAllocated": 0,
            "systemPowerAllocated": 0,
            "powerRemaining": 0,
            "poeVersion": "string",
            "chassisCount": 0,
            "moduleCount": 0,
            "moduleDetails": [
              {
                "moduleId": "string",
                "chassisId": "string",
                "modulePortCount": 0,
                "moduleUsedPortCount": 0,
                "moduleFreePortCount": 0,
                "modulePowerConsumed": 0,
                "modulePoePowerConsumed": 0,
                "moduleSystemPowerConsumed": 0,
                "modulePowerBudget": 0,
                "modulePoePowerAllocated": 0,
                "moduleSystemPowerAllocated": 0,
                "modulePowerRemaining": 0,
                "interfacePowerMax": 0
              }
            ]
          },
          "fabricMetricsDetails": {
            "overallFabricScore": 0,
            "fabricTransitScore": 0,
            "fabricSiteScore": 0,
            "fabricVnScore": 0,
            "fabsiteFcpScore": 0,
            "fabsiteInfraScore": 0,
            "fabsiteFsconnScore": 0,
            "vnExitScore": 0,
            "vnFcpScore": 0,
            "vnStatusScore": 0,
            "vnServiceScore": 0,
            "transitControlPlaneScore": 0,
            "transitServicesScore": 0,
            "tcpConnScore": 0,
            "bgpBgpSiteScore": 0,
            "vniStatusScore": 0,
            "pubsubTransitConnScore": 0,
            "bgpPeerInfraVnScore": 0,
            "internetAvailScore": 0,
            "bgpEvpnScore": 0,
            "lispTransitConnScore": 0,
            "ctsEnvDataDownloadScore": 0,
            "pubsubInfraVnScore": 0,
            "peerScore": 0,
            "bgpPeerScore": 0,
            "remoteInternetAvailScore": 0,
            "bgpTcpScore": 0,
            "pubsubSessionScore": 0,
            "aaaStatusScore": 0,
            "lispCpConnScore": 0,
            "bgpPubsubSiteScore": 0,
            "mcastScore": 0,
            "portChannelScore": 0
          },
          "aggregateAttributes": [
            {
              "name": "string",
              "function": "string",
              "value": 0
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": "string",
        "order": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: lan_automation_log_by_serial_number_info
short_description: Information module for Lan Automation
  Log By Serial Number
description:
  - Get Lan Automation Log By Serial Number by id. -
    > Invoke this API to get the LAN Automation session
    logs for individual devices based on the given LAN
    Automation session id and device serial number.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. LAN Automation session identifier.
    type: str
  serialNumber:
    description:
      - SerialNumber path parameter. Device serial number.
    type: str
  logLevel:
    description:
      - >
        LogLevel query parameter. Supported levels are
        ERROR, INFO, WARNING, TRACE, CONFIG and ALL.
        Specifying ALL will display device specific
        logs with the exception of CONFIG logs. In order
        to view CONFIG logs along with the remaining
        logs, please leave the query parameter blank.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for LAN Automation
      LANAutomationLogsForIndividualDevices
    description: Complete reference of the LANAutomationLogsForIndividualDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-logs-for-individual-devices
notes:
  - SDK Method used are
    lan_automation.LanAutomation.lan_automation_logs_for_individual_devices,
  - Paths used are
    get /dna/intent/api/v1/lan-automation/log/{id}/{serialNumber},
"""

EXAMPLES = r"""
---
- name: Get Lan Automation Log By Serial Number by id
  cisco.dnac.lan_automation_log_by_serial_number_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    logLevel: string
    id: string
    serialNumber: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "nwOrchId": "string",
          "logs": [
            {
              "logLevel": "string",
              "timeStamp": "string",
              "record": "string"
            }
          ],
          "serialNumber": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: global_credential_v2
short_description: Resource module for Global Credential
  V2
description:
  - Manage operations create, update and delete of the
    resource Global Credential V2. - > API to create
    new global credentials. Multiple credentials of
    various types can be passed at once. Please refer
    sample Request Body for more information.
  - Delete a global credential. Only 'id' of the credential
    has to be passed. - > API to update device credentials.
    Multiple credentials can be passed at once, but
    only a single credential of a given type can be
    passed at once. Please refer sample Request Body
    for more information.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cliCredential:
    description: Global Credential V2's cliCredential.
    suboptions:
      description:
        description: Description for CLI credential.
        type: str
      enablePassword:
        description: CLI Enable Password.
        type: str
      id:
        description: Id of the CLI Credential in UUID
          format.
        type: str
      password:
        description: CLI Password.
        type: str
      username:
        description: CLI Username.
        type: str
    type: dict
  httpsRead:
    description: Global Credential V2's httpsRead.
    suboptions:
      description:
        description: Description for HTTP(S) Read Credentials.
        type: str
      id:
        description: Id of the HTTP(S) Read Credential
          in UUID format.
        type: str
      password:
        description: HTTP(S) Read Password.
        type: str
      port:
        description: HTTP(S) Port.
        type: int
      username:
        description: HTTP(S) Read Username.
        type: str
    type: dict
  httpsWrite:
    description: Global Credential V2's httpsWrite.
    suboptions:
      description:
        description: Description for HTTP(S) Write Credentials.
        type: str
      id:
        description: Id of the HTTP(S) Read Credential
          in UUID format.
        type: str
      password:
        description: HTTP(S) Write Password.
        type: str
      port:
        description: HTTP(S) Port.
        type: int
      username:
        description: HTTP(S) Write Username.
        type: str
    type: dict
  id:
    description: Id path parameter. Global Credential
      id.
    type: str
  snmpV2cRead:
    description: Global Credential V2's snmpV2cRead.
    suboptions:
      description:
        description: Description for Snmp RO community.
        type: str
      id:
        description: Id of the SNMP Read Credential
          in UUID format.
        type: str
      readCommunity:
        description: Snmp RO community.
        type: str
    type: dict
  snmpV2cWrite:
    description: Global Credential V2's snmpV2cWrite.
    suboptions:
      description:
        description: Description for Snmp RW community.
        type: str
      id:
        description: Id of the SNMP Write Credential
          in UUID format.
        type: str
      writeCommunity:
        description: Snmp RW community.
        type: str
    type: dict
  snmpV3:
    description: Global Credential V2's snmpV3.
    suboptions:
      authPassword:
        description: Auth Password for SNMP V3.
        type: str
      authType:
        description: SNMP auth protocol. SHA' or 'MD5'.
        type: str
      description:
        description: Description for Snmp V3 Credential.
        type: str
      id:
        description: Id of the SNMP V3 Credential in
          UUID format.
        type: str
      privacyPassword:
        description: Privacy Password for SNMP privacy.
        type: str
      privacyType:
        description: SNMP privacy protocol. 'AES128','AES192','AES256'.
        type: str
      snmpMode:
        description: Mode of SNMP. 'AUTHPRIV' or 'AUTHNOPRIV'
          or 'NOAUTHNOPRIV'.
        type: str
      username:
        description: SNMP V3 Username.
        type: str
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Discovery
      CreateGlobalCredentialsV2
    description: Complete reference of the CreateGlobalCredentialsV2
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-global-credentials-v-2
  - name: Cisco DNA Center documentation for Discovery
      DeleteGlobalCredentialV2
    description: Complete reference of the DeleteGlobalCredentialV2
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-global-credential-v-2
  - name: Cisco DNA Center documentation for Discovery
      UpdateGlobalCredentialsV2
    description: Complete reference of the UpdateGlobalCredentialsV2
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-global-credentials-v-2
notes:
  - SDK Method used are
    discovery.Discovery.create_global_credentials_v2,
    discovery.Discovery.delete_global_credential_v2,
    discovery.Discovery.update_global_credentials_v2,
  - Paths used are
    post /dna/intent/api/v2/global-credential,
    delete /dna/intent/api/v2/global-credential/{id},
    put /dna/intent/api/v2/global-credential,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.global_credential_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cliCredential:
      description: string
      enablePassword: string
      id: string
      password: string
      username: string
    httpsRead:
      description: string
      id: string
      password: string
      port: 0
      username: string
    httpsWrite:
      description: string
      id: string
      password: string
      port: 0
      username: string
    snmpV2cRead:
      description: string
      id: string
      readCommunity: string
    snmpV2cWrite:
      description: string
      id: string
      writeCommunity: string
    snmpV3:
      authPassword: string
      authType: string
      description: string
      id: string
      privacyPassword: string
      privacyType: string
      snmpMode: string
      username: string
- name: Create
  cisco.dnac.global_credential_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cliCredential:
      - description: string
        enablePassword: string
        password: string
        username: string
    httpsRead:
      - description: string
        password: string
        port: 0
        username: string
    httpsWrite:
      - description: string
        password: string
        port: 0
        username: string
    snmpV2cRead:
      - description: string
        readCommunity: string
    snmpV2cWrite:
      - description: string
        writeCommunity: string
    snmpV3:
      - authPassword: string
        authType: string
        description: string
        privacyPassword: string
        privacyType: string
        snmpMode: string
        username: string
- name: Delete by id
  cisco.dnac.global_credential_v2:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: feature_templates_wireless_rrm_fra_configurations
short_description: Resource module for Feature Templates
  Wireless Rrm Fra Configurations
description:
  - Manage operation create of the resource Feature
    Templates Wireless Rrm Fra Configurations.
  - This API allows users to create a RRM FRA configuration
    feature template.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  designName:
    description: The feature template design name. `Note
      ` The following characters are not allowed % &
      < > ' /.
    type: str
  featureAttributes:
    description: Feature Templates Wireless Rrm Fra
      Configurations's featureAttributes.
    suboptions:
      fraFreeze:
        description: Flexible Radio Assignment Freeze
          is supported only on Cisco IOS-XE based Wireless
          Controllers running version >= 17.6 for 2_4GHZ_5GHZ
          radioband and version >= 17.9 for 5GHZ_6GHZ
          radioband.
        type: bool
      fraInterval:
        description: Flexible Radio Assignment Interval.
        type: int
      fraSensitivity:
        description: Flexible Radio Assignment Sensitivity
          values HIGHER,EVEN_HIGHER and SUPER_HIGH are
          supported only on Cisco IOS-XE based Wireless
          Controllers running 17.5 and above and FRA
          Sensitivity is only supported for 2_4GHZ_5GHZ
          radio band.
        type: str
      fraStatus:
        description: Flexible Radio Assignment Status.
        type: bool
      radioBand:
        description: Radio Band 5GHZ_6GHZ is supported
          only on Cisco IOS-XE based Wireless Controllers
          running 17.9.1 and above.
        type: str
    type: dict
  unlockedAttributes:
    description: Attributes unlocked in design can be
      changed at device provision time. `Note ` unlockedAttributes
      can only contain the attributes defined under
      featureAttributes.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      CreateRRMFRAConfigurationFeatureTemplate
    description: Complete reference of the CreateRRMFRAConfigurationFeatureTemplate
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-rrmfra-configuration-feature-template
notes:
  - SDK Method used are
    wireless.Wireless.create_r_r_m_f_r_a_configuration_feature_template,
  - Paths used are
    post /dna/intent/api/v1/featureTemplates/wireless/rrmFraConfigurations,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.feature_templates_wireless_rrm_fra_configurations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    designName: string
    featureAttributes:
      fraFreeze: true
      fraInterval: 0
      fraSensitivity: string
      fraStatus: true
      radioBand: string
    unlockedAttributes:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_sites_id_info
short_description: Information module for Energy Sites
  Id
description:
  - Get Energy Sites Id by id. - > Retrieve the energy
    summary data for a specific site based on the site
    ID. For detailed information about the usage of
    the API, please refer to the Open API specification
    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    sitesEnergy-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The UUID of the Site. (Ex.
        "6bef213c-19ca-4170-8375-b694e251101c").
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `endTime` is not provided,
        API will default to one day after `startTime`.
        If `startTime` is not provided either, API will
        default to current time.
    type: float
  views:
    description:
      - >
        Views query parameter. The specific summary
        view being requested. This is an optional parameter
        which can be passed to get one or more of the
        specific health data summaries associated with
        sites. ### Response data proviced by each view
        1. **Site** id, siteHierarchy, siteHierarchyId,
        siteType, latitude, longitude 2. **Energy**
        energyConsumed, estimatedCost, estimatedEmission,
        carbonIntensity, numberOfDevices When this query
        parameter is not added the default summaries
        are **site,energy** Examples views=site (single
        view requested) views=site,energy (multiple
        views requested).
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. Supported Attributes
        id, siteHierarchy, siteHierarchyId, siteType,
        latitude, longitude, energyConsumed, estimatedCost,
        estimatedEmission, carbonIntensity, numberOfDevices
        If length of attribute list is too long, please
        use 'view' param instead. Examples attribute=siteHierarchy
        (single attribute requested) attribute=siteHierarchy&attribute=energyConsumed
        (multiple attributes requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of
        device categories. Note that this filter specifies
        which devices will be included when calculating
        energy consumption values, rather than specifying
        the list of returned sites. Examples `deviceCategory=Switch`
        (single device category requested) `deviceCategory=Switch&deviceCategory=Router`
        (multiple device categories with comma separator).
    type: str
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously
        processed & stored data. When this parameter
        is used, the rest of the request params will
        be ignored.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sites GetSiteEnergyByID
    description: Complete reference of the GetSiteEnergyByID
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-energy-by-id
notes:
  - SDK Method used are
    sites.Sites.get_site_energy_by_id,
  - Paths used are
    get /dna/data/api/v1/energy/sites/{id},
"""

EXAMPLES = r"""
---
- name: Get Energy Sites Id by id
  cisco.dnac.energy_sites_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    views: string
    attribute: string
    deviceCategory: string
    taskId: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "siteName": "string",
        "siteHierarchy": "string",
        "siteHierarchyId": "string",
        "siteType": "string",
        "latitude": 0,
        "longitude": 0,
        "deviceCategories": [
          "string"
        ],
        "energyConsumed": 0,
        "estimatedCost": 0,
        "estimatedEmission": 0,
        "carbonIntensity": 0,
        "numberOfDevices": 0
      },
      "version": "string"
    }
"""
